@@ -27,7 +27,6 @@ open LittleEndian
 
 open CommonOptions
 open CommonTypes
-open CommonGlobals
 open CommonFile
 open CommonGlobals
 
@@ -326,7 +325,7 @@ let server_send_share compressed sock msg =
       Buffer.reset buf;
       let s_c =
         if compressed then
-          Autoconf.zlib__compress_string s
+          Zlib.compress_string s
         else
           s
       in
