@@ -18,31 +18,17 @@
 *)
 
 open Int64ops
-open Queues
 open Printf2
-open Md4
-open Options
 
 open BasicSocket
 open TcpBufferedSocket
 
-open CommonShared
-open CommonUploads
 open CommonOptions
-open CommonDownloads
-open CommonInteractive
 open CommonClient
-open CommonComplexOptions
 open CommonTypes
-open CommonFile
-open CommonGlobals
-open CommonDownloads
 
 open FileTPTypes
-open FileTPOptions
 open FileTPGlobals
-open FileTPComplexOptions
-open FileTPProtocol
 
 open FileTPClients
 
