@@ -19,8 +19,6 @@
 
 open Printf2
 open BasicSocket
-open TcpBufferedSocket
-open Ip_set
 
 let verbose = ref false
 
@@ -247,15 +245,15 @@ let error_page reason my_ip my_port =
       Printf.sprintf "The requested URL %s was not found on this server." (html_escaped url)
   in
   let reject_message = Printf.sprintf
-"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n<html>
-<head><title>%d %s</title></head>\n<h1>%d %s</h1>\n%s
+"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n<html>\
+<head><title>%d %s</title></head>\n<h1>%d %s</h1>\n%s\
 <hr><address>MLDonkey/%s at %s Port %d</address></html>"
     http_code error_text http_code error_text error_text_long
     Autoconf.current_version (Ip.to_string my_ip) my_port
   in
   let headers = String.concat "\n" (List.map (fun (k,v) -> k ^ ": " ^ v) headers) in
   Printf.sprintf
-"HTTP/1.1 %d %s\nServer: MLDonkey/%s\nConnection: close
+"HTTP/1.1 %d %s\nServer: MLDonkey/%s\nConnection: close\n\
 Content-Type: text/html; charset=iso-8859-1\n%sContent-length: %d\r\n"
     http_code error_text Autoconf.current_version headers (String.length reject_message), reject_message,
   Printf.sprintf "%d %s" http_code error_text
@@ -935,8 +933,6 @@ let parse_range range =
   x, y, z
     *)
 
-open Int64ops
-
 (*  Range: bytes=31371876- *)
 let request_range r =
   if !verbose then List.iter (fun (h, v1) ->
